-file("/usr/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(toml_lexer).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("src/toml_lexer.xrl", 51).

-file("/usr/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,_Tlen,_Ics1,_L1,_S1} ->
            string_cont(yysuf(Tcs, Alen), L0, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->       % Use last accept match
            token_cont(yysuf(Tcs, Alen1), L0, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,_L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            tokens_cont(yysuf(Tcs, Alen1), L0, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,_Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            skip_cont(yysuf(Tcs, Alen1), L1, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("src/toml_lexer.erl", 284).
yystate() -> 96.

yystate(99, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line};
yystate(98, [13|Ics], Line, Tlen, _, _) ->
    yystate(94, Ics, Line, Tlen+1, 19, Tlen);
yystate(98, [10|Ics], Line, Tlen, _, _) ->
    yystate(98, Ics, Line+1, Tlen+1, 19, Tlen);
yystate(98, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line,98};
yystate(97, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line};
yystate(96, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(91, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(95, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(85, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(99, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(97, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [61|Ics], Line, Tlen, Action, Alen) ->
    yystate(89, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(90, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(94, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line+1, Tlen+1, Action, Alen);
yystate(96, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(85, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 90 ->
    yystate(93, Ics, Line, Tlen+1, Action, Alen);
yystate(96, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(93, Ics, Line, Tlen+1, Action, Alen);
yystate(96, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,96};
yystate(95, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line};
yystate(94, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line+1, Tlen+1, Action, Alen);
yystate(94, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,94};
yystate(93, [95|Ics], Line, Tlen, _, _) ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(93, [45|Ics], Line, Tlen, _, _) ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(93, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(93, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(93, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(93, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,93};
yystate(92, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(88, Ics, Line, Tlen+1, Action, Alen);
yystate(92, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,92};
yystate(91, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line};
yystate(90, [32|Ics], Line, Tlen, _, _) ->
    yystate(90, Ics, Line, Tlen+1, 18, Tlen);
yystate(90, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line,90};
yystate(89, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line};
yystate(88, [52|Ics], Line, Tlen, Action, Alen) ->
    yystate(84, Ics, Line, Tlen+1, Action, Alen);
yystate(88, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,88};
yystate(87, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(87, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,87};
yystate(86, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(86, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(82, Ics, Line, Tlen+1, Action, Alen);
yystate(86, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(86, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(86, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(86, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(86, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(86, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,86};
yystate(85, [95|Ics], Line, Tlen, _, _) ->
    yystate(85, Ics, Line, Tlen+1, 5, Tlen);
yystate(85, [46|Ics], Line, Tlen, _, _) ->
    yystate(81, Ics, Line, Tlen+1, 5, Tlen);
yystate(85, [45|Ics], Line, Tlen, _, _) ->
    yystate(93, Ics, Line, Tlen+1, 5, Tlen);
yystate(85, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(85, Ics, Line, Tlen+1, 5, Tlen);
yystate(85, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(93, Ics, Line, Tlen+1, 5, Tlen);
yystate(85, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(93, Ics, Line, Tlen+1, 5, Tlen);
yystate(85, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,85};
yystate(84, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(80, Ics, Line, Tlen+1, Action, Alen);
yystate(84, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,84};
yystate(83, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(87, Ics, Line, Tlen+1, Action, Alen);
yystate(83, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,83};
yystate(82, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line};
yystate(81, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(77, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen+1, Action, Alen);
yystate(81, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,81};
yystate(80, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(76, Ics, Line, Tlen+1, Action, Alen);
yystate(80, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,80};
yystate(79, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(83, Ics, Line, Tlen+1, Action, Alen);
yystate(79, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,79};
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(78, [C|Ics], Line, Tlen, Action, Alen) when C >= 11 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(78, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,78};
yystate(77, [101|Ics], Line, Tlen, _, _) ->
    yystate(73, Ics, Line, Tlen+1, 6, Tlen);
yystate(77, [95|Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen+1, 6, Tlen);
yystate(77, [69|Ics], Line, Tlen, _, _) ->
    yystate(73, Ics, Line, Tlen+1, 6, Tlen);
yystate(77, [46|Ics], Line, Tlen, _, _) ->
    yystate(81, Ics, Line, Tlen+1, 6, Tlen);
yystate(77, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen+1, 6, Tlen);
yystate(77, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,77};
yystate(76, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(72, Ics, Line, Tlen+1, Action, Alen);
yystate(76, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,76};
yystate(75, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(79, Ics, Line, Tlen+1, Action, Alen);
yystate(75, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,75};
yystate(74, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(74, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(74, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(74, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(74, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(74, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(74, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(74, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,74};
yystate(73, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(73, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,73};
yystate(72, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(72, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,72};
yystate(71, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(75, Ics, Line, Tlen+1, Action, Alen);
yystate(71, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,71};
yystate(70, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(70, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(70, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(70, [C|Ics], Line, Tlen, Action, Alen) when C >= 35 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(70, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,70};
yystate(69, [95|Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen+1, 6, Tlen);
yystate(69, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(69, Ics, Line, Tlen+1, 6, Tlen);
yystate(69, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,69};
yystate(68, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(68, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,68};
yystate(67, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(67, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,67};
yystate(66, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 122 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 124 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(66, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,66};
yystate(65, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(65, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(65, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,65};
yystate(64, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(64, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,64};
yystate(63, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(67, Ics, Line, Tlen+1, Action, Alen);
yystate(63, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,63};
yystate(62, [34|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(70, Ics, Line, Tlen+1, 2, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(70, Ics, Line, Tlen+1, 2, Tlen);
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 35 ->
    yystate(70, Ics, Line, Tlen+1, 2, Tlen);
yystate(62, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,62};
yystate(61, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line};
yystate(60, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(56, Ics, Line, Tlen+1, Action, Alen);
yystate(60, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,60};
yystate(59, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(59, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,59};
yystate(58, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(58, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(58, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(58, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(58, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 124 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(58, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(58, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,58};
yystate(57, [95|Ics], Line, Tlen, _, _) ->
    yystate(85, Ics, Line, Tlen+1, 7, Tlen);
yystate(57, [45|Ics], Line, Tlen, _, _) ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(57, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(85, Ics, Line, Tlen+1, 7, Tlen);
yystate(57, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(57, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(93, Ics, Line, Tlen+1, 7, Tlen);
yystate(57, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,57};
yystate(56, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(52, Ics, Line, Tlen+1, Action, Alen);
yystate(56, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,56};
yystate(55, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(55, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,55};
yystate(54, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(58, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 50 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(54, [C|Ics], Line, Tlen, Action, Alen) when C >= 52 ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(54, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,54};
yystate(53, Ics, Line, Tlen, _, _) ->
    {17,Tlen,Ics,Line};
yystate(52, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(52, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,52};
yystate(51, [90|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 9, Tlen);
yystate(51, [45|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 9, Tlen);
yystate(51, [43|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 9, Tlen);
yystate(51, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,51};
yystate(50, [123|Ics], Line, Tlen, _, _) ->
    yystate(54, Ics, Line, Tlen+1, 1, Tlen);
yystate(50, [34|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 1, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(70, Ics, Line, Tlen+1, 1, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(70, Ics, Line, Tlen+1, 1, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 122 ->
    yystate(70, Ics, Line, Tlen+1, 1, Tlen);
yystate(50, [C|Ics], Line, Tlen, _, _) when C >= 124 ->
    yystate(70, Ics, Line, Tlen+1, 1, Tlen);
yystate(50, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line,50};
yystate(49, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(49, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(49, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,49};
yystate(48, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(48, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,48};
yystate(47, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(47, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,47};
yystate(46, [92|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 2, Tlen);
yystate(46, [34|Ics], Line, Tlen, _, _) ->
    yystate(50, Ics, Line, Tlen+1, 2, Tlen);
yystate(46, [10|Ics], Line, Tlen, _, _) ->
    yystate(86, Ics, Line+1, Tlen+1, 2, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(74, Ics, Line, Tlen+1, 2, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 33 ->
    yystate(74, Ics, Line, Tlen+1, 2, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 35, C =< 91 ->
    yystate(74, Ics, Line, Tlen+1, 2, Tlen);
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 93 ->
    yystate(74, Ics, Line, Tlen+1, 2, Tlen);
yystate(46, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,46};
yystate(45, [95|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 5, Tlen);
yystate(45, [46|Ics], Line, Tlen, _, _) ->
    yystate(81, Ics, Line, Tlen+1, 5, Tlen);
yystate(45, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(45, Ics, Line, Tlen+1, 5, Tlen);
yystate(45, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,45};
yystate(44, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(44, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,44};
yystate(43, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(43, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,43};
yystate(42, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 124 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(42, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,42};
yystate(41, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line+1, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 122 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(41, [C|Ics], Line, Tlen, Action, Alen) when C >= 124 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(41, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,41};
yystate(40, [84|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 10, Tlen);
yystate(40, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,40};
yystate(39, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(39, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,39};
yystate(38, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(38, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(38, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,38};
yystate(37, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line+1, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 50 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(37, [C|Ics], Line, Tlen, Action, Alen) when C >= 52 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(37, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,37};
yystate(36, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(36, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,36};
yystate(35, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(35, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,35};
yystate(34, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(38, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 122 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 124 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(34, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,34};
yystate(33, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line+1, Tlen+1, Action, Alen);
yystate(33, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 124 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(33, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,33};
yystate(32, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen+1, Action, Alen);
yystate(32, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,32};
yystate(31, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(31, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,31};
yystate(30, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(30, [C|Ics], Line, Tlen, Action, Alen) when C >= 35 ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(30, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,30};
yystate(29, [123|Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen+1, 3, Tlen);
yystate(29, [39|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 3, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(9, Ics, Line, Tlen+1, 3, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 38 ->
    yystate(9, Ics, Line, Tlen+1, 3, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 40, C =< 122 ->
    yystate(9, Ics, Line, Tlen+1, 3, Tlen);
yystate(29, [C|Ics], Line, Tlen, _, _) when C >= 124 ->
    yystate(9, Ics, Line, Tlen+1, 3, Tlen);
yystate(29, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line,29};
yystate(28, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(28, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,28};
yystate(27, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(27, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,27};
yystate(26, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(74, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(82, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 124 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(26, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,26};
yystate(25, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(21, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 50 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(25, [C|Ics], Line, Tlen, Action, Alen) when C >= 52 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(25, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,25};
yystate(24, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(24, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,24};
yystate(23, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line};
yystate(22, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [51|Ics], Line, Tlen, Action, Alen) ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(82, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 50 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 52, C =< 91 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(22, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(22, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,22};
yystate(21, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(17, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 124 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(21, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,21};
yystate(20, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(16, Ics, Line, Tlen+1, Action, Alen);
yystate(20, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,20};
yystate(19, [90|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 9, Tlen);
yystate(19, [46|Ics], Line, Tlen, _, _) ->
    yystate(27, Ics, Line, Tlen+1, 9, Tlen);
yystate(19, [45|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 9, Tlen);
yystate(19, [43|Ics], Line, Tlen, _, _) ->
    yystate(55, Ics, Line, Tlen+1, 9, Tlen);
yystate(19, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,19};
yystate(18, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(78, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(82, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line+1, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 122 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(18, [C|Ics], Line, Tlen, Action, Alen) when C >= 124 ->
    yystate(86, Ics, Line, Tlen+1, Action, Alen);
yystate(18, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,18};
yystate(17, [39|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 4, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(9, Ics, Line, Tlen+1, 4, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 38 ->
    yystate(9, Ics, Line, Tlen+1, 4, Tlen);
yystate(17, [C|Ics], Line, Tlen, _, _) when C >= 40 ->
    yystate(9, Ics, Line, Tlen+1, 4, Tlen);
yystate(17, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,17};
yystate(16, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(16, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,16};
yystate(15, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(15, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,15};
yystate(14, [13|Ics], Line, Tlen, Action, Alen) ->
    yystate(6, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [11|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [12|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line+1, Tlen+1, Action, Alen);
yystate(14, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(14, [C|Ics], Line, Tlen, Action, Alen) when C >= 14 ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(14, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,14};
yystate(13, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(13, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(13, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(13, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(13, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 122 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(13, [C|Ics], Line, Tlen, Action, Alen) when C >= 124 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(13, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,13};
yystate(12, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(8, Ics, Line, Tlen+1, Action, Alen);
yystate(12, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,12};
yystate(11, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(11, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,11};
yystate(10, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line};
yystate(9, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(9, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(9, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(9, [C|Ics], Line, Tlen, Action, Alen) when C >= 40 ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(9, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,9};
yystate(8, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(8, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,8};
yystate(7, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(11, Ics, Line, Tlen+1, Action, Alen);
yystate(7, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,7};
yystate(6, [13|Ics], Line, Tlen, _, _) ->
    yystate(6, Ics, Line, Tlen+1, 0, Tlen);
yystate(6, [11|Ics], Line, Tlen, _, _) ->
    yystate(14, Ics, Line, Tlen+1, 0, Tlen);
yystate(6, [12|Ics], Line, Tlen, _, _) ->
    yystate(14, Ics, Line, Tlen+1, 0, Tlen);
yystate(6, [10|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line+1, Tlen+1, 0, Tlen);
yystate(6, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(14, Ics, Line, Tlen+1, 0, Tlen);
yystate(6, [C|Ics], Line, Tlen, _, _) when C >= 14 ->
    yystate(14, Ics, Line, Tlen+1, 0, Tlen);
yystate(6, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line,6};
yystate(5, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(5, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line+1, Tlen+1, Action, Alen);
yystate(5, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(5, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(5, [C|Ics], Line, Tlen, Action, Alen) when C >= 40 ->
    yystate(5, Ics, Line, Tlen+1, Action, Alen);
yystate(5, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,5};
yystate(4, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(4, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,4};
yystate(3, [127|Ics], Line, Tlen, Action, Alen) ->
    yystate(7, Ics, Line, Tlen+1, Action, Alen);
yystate(3, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,3};
yystate(2, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(2, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line+1, Tlen+1, Action, Alen);
yystate(2, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(2, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(2, [C|Ics], Line, Tlen, Action, Alen) when C >= 40 ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(2, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,2};
yystate(1, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line};
yystate(0, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line, Tlen+1, Action, Alen);
yystate(0, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, _, _, _) ->
    yyaction_0();
yyaction(1, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_1(TokenChars, TokenLine);
yyaction(2, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_2(TokenChars, TokenLine);
yyaction(3, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_3(TokenChars, TokenLine);
yyaction(4, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_4(TokenChars, TokenLine);
yyaction(5, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_5(TokenChars, TokenLine);
yyaction(6, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_6(TokenChars, TokenLine);
yyaction(7, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_7(TokenChars, TokenLine);
yyaction(8, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_8(TokenChars, TokenLine);
yyaction(9, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_9(TokenChars, TokenLine);
yyaction(10, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_10(TokenChars, TokenLine);
yyaction(11, _, _, TokenLine) ->
    yyaction_11(TokenLine);
yyaction(12, _, _, TokenLine) ->
    yyaction_12(TokenLine);
yyaction(13, _, _, TokenLine) ->
    yyaction_13(TokenLine);
yyaction(14, _, _, TokenLine) ->
    yyaction_14(TokenLine);
yyaction(15, _, _, TokenLine) ->
    yyaction_15(TokenLine);
yyaction(16, _, _, TokenLine) ->
    yyaction_16(TokenLine);
yyaction(17, _, _, TokenLine) ->
    yyaction_17(TokenLine);
yyaction(18, _, _, _) ->
    yyaction_18();
yyaction(19, _, _, _) ->
    yyaction_19();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/0}).
-file("src/toml_lexer.xrl", 22).
yyaction_0() ->
     skip_token .

-compile({inline,yyaction_1/2}).
-file("src/toml_lexer.xrl", 24).
yyaction_1(TokenChars, TokenLine) ->
     { token, { lit_string_basic, TokenLine, TokenChars } } .

-compile({inline,yyaction_2/2}).
-file("src/toml_lexer.xrl", 25).
yyaction_2(TokenChars, TokenLine) ->
     { token, { lit_string_basic_multi, TokenLine, TokenChars } } .

-compile({inline,yyaction_3/2}).
-file("src/toml_lexer.xrl", 26).
yyaction_3(TokenChars, TokenLine) ->
     { token, { lit_string_literal, TokenLine, TokenChars } } .

-compile({inline,yyaction_4/2}).
-file("src/toml_lexer.xrl", 27).
yyaction_4(TokenChars, TokenLine) ->
     { token, { lit_string_literal_multi, TokenLine, TokenChars } } .

-compile({inline,yyaction_5/2}).
-file("src/toml_lexer.xrl", 29).
yyaction_5(TokenChars, TokenLine) ->
     { token, { lit_integer, TokenLine, TokenChars } } .

-compile({inline,yyaction_6/2}).
-file("src/toml_lexer.xrl", 30).
yyaction_6(TokenChars, TokenLine) ->
     { token, { lit_float, TokenLine, TokenChars } } .

-compile({inline,yyaction_7/2}).
-file("src/toml_lexer.xrl", 31).
yyaction_7(TokenChars, TokenLine) ->
     { token, { key_bare, TokenLine, TokenChars } } .

-compile({inline,yyaction_8/2}).
-file("src/toml_lexer.xrl", 33).
yyaction_8(TokenChars, TokenLine) ->
     { token, { lit_datetime1, TokenLine, TokenChars } } .

-compile({inline,yyaction_9/2}).
-file("src/toml_lexer.xrl", 34).
yyaction_9(TokenChars, TokenLine) ->
     { token, { lit_datetime2, TokenLine, TokenChars } } .

-compile({inline,yyaction_10/2}).
-file("src/toml_lexer.xrl", 35).
yyaction_10(TokenChars, TokenLine) ->
     { token, { lit_datetime3, TokenLine, TokenChars } } .

-compile({inline,yyaction_11/1}).
-file("src/toml_lexer.xrl", 37).
yyaction_11(TokenLine) ->
     { token, { '=', TokenLine } } .

-compile({inline,yyaction_12/1}).
-file("src/toml_lexer.xrl", 38).
yyaction_12(TokenLine) ->
     { token, { '[', TokenLine } } .

-compile({inline,yyaction_13/1}).
-file("src/toml_lexer.xrl", 39).
yyaction_13(TokenLine) ->
     { token, { ']', TokenLine } } .

-compile({inline,yyaction_14/1}).
-file("src/toml_lexer.xrl", 40).
yyaction_14(TokenLine) ->
     { token, { '{', TokenLine } } .

-compile({inline,yyaction_15/1}).
-file("src/toml_lexer.xrl", 41).
yyaction_15(TokenLine) ->
     { token, { '}', TokenLine } } .

-compile({inline,yyaction_16/1}).
-file("src/toml_lexer.xrl", 42).
yyaction_16(TokenLine) ->
     { token, { '.', TokenLine } } .

-compile({inline,yyaction_17/1}).
-file("src/toml_lexer.xrl", 43).
yyaction_17(TokenLine) ->
     { token, { ',', TokenLine } } .

-compile({inline,yyaction_18/0}).
-file("src/toml_lexer.xrl", 46).
yyaction_18() ->
     skip_token .

-compile({inline,yyaction_19/0}).
-file("src/toml_lexer.xrl", 47).
yyaction_19() ->
     skip_token .

-file("/usr/lib/erlang/lib/parsetools-2.1.1/include/leexinc.hrl", 290).
